@@ -68,6 +68,9 @@ module MCollective
                 msg[:senderid] = Digest::MD5.hexdigest(msg[:senderid]) if ENV.include?("MCOLLECTIVE_ANON")
 
                 raise(MsgDoesNotMatchRequestID, "Message reqid #{requestid} does not match our reqid #{msg[:requestid]}") if msg[:requestid] != requestid
+            rescue SecurityValidationFailed => e
+                @log.warn("Ignoring a message that did not pass security validations")
+                retry
             rescue MsgDoesNotMatchRequestID => e
                 @log.debug("Ignoring a message for some other client")
                 retry
